*------------------------------------------------------------------------------*
Procedure Connect
*------------------------------------------------------------------------------*
/*

	Class TMySQLServer:

		- Manages access to a MySQL server and returns an oServer object 
		to which you'll send all your queries.

		- Administra el acceso a un servidor MySql y retorna un objeto
		oServer al cual se le enviaran los comandos SQL.

	Method New(cServer, cUser, cPassword): 

		- Opens connection to a server, returns a server object.

		- Abre una conexion a un servidor, retorna un objeto servidor.

	Method NetErr():

		- Returns .T. if something went wrong

		- Retorna .T. en caso de error.

	Method Error():

		- Returns textual description of last error.

		- Retorna la descripcion del ultimo error.

	Method SelectDB(cDBName):

		- Which data base I will use for subsequent queries.

		- Selecciona la base de datos que se usara en los siguientes
		consultas.

*/

	// Connect

	oServer := TMySQLServer():New("localhost", "root", "capricornio1973") //<-modifica tus datos de conexión

	// Check For Error

	If oServer:NetErr()

		MsgStop(oServer:Error())
		Win_1.Title := 'MySql Basic Sample - Not Connected' 

	Else

		Win_1.Title := 'MySql Basic Sample - Connected' 

	EndIf

Return


*------------------------------------------------------------------------------*
Procedure Disconnect()
*------------------------------------------------------------------------------*
/*..............................................................................

	Class TMySQLServer - Method Destroy():

		- Closes connection to server.
		
		- Cierra la conexion con un servidor.

..............................................................................*/

	oServer:Destroy()
	Win_1.Title := 'MySql Basic Sample - Not Connected' 

Return


*------------------------------------------------------------------------------*
Function My_SQL_Database_Connect( cDatabase )
*------------------------------------------------------------------------------*
/*..............................................................................

	Class TMySQLServer - Method ListDBs()

		- Returns an array with list of data bases available.

		- Retorna un array con la lista de bases de datos disponibles.

	Class TMySQLServer - ListTables()

		- Returns an array with list of available tables in current
		database.

		- Retorna un array con la lista de tablas disponibles en la
		base de datos actual.

..............................................................................*/

Local i             := 0
Local aDatabaseList := {}                                           

	cDatabase:= Lower(cDatabase)
	If oServer == Nil 
		MsgInfo("Not connected to SQL server!")
		Return Nil
	EndIf

	aDatabaseList:= oServer:ListDBs()
	If oServer:NetErr() 
		MsGInfo("Error verifying database list: " + oServer:Error())
		Release Window ALL
	Endif 

	If AScan( aDatabaseList, Lower(cDatabase) ) == 0
		IF MsgYesNo( "Database "+cDatabase+" doesn't exist!"+chr(13)+"Do you want to create ?")
         My_SQL_Database_Create( cDatabase )
      ELSE
         Return Nil
      ENDIF
	EndIf 

	oServer:SelectDB( cDatabase )
	If oServer:NetErr() 
		MsgStop("Error connecting to database "+cDatabase+": "+oServer:Error() )
	Endif 

Return Nil


*------------------------------------------------------------------------------*
Function  My_SQL_Database_Create( cDatabase )
*------------------------------------------------------------------------------*
Local i:= 0
Local aDatabaseList:= {} 

	cDatabase:=Lower(cDatabase)

	If oServer == Nil 
		MsgInfo("Not connected to SQL server!")
		Return Nil
	EndIf

	aDatabaseList:= oServer:ListDBs()

	If oServer:NetErr() 
		MsGInfo("Error verifying database list: " + oServer:Error())
		Release Window ALL
	Endif 

	If AScan( aDatabaseList, Lower(cDatabase) ) != 0
		MsgINFO( "Database allready exists!")
		Return Nil
	EndIf 

	oServer:CreateDatabase( cDatabase )

	If oServer:NetErr() 
		MsGInfo("Error creating database: " + oServer:Error() )
	Endif 

Return Nil